#################################################### VERSIONING INFORMATION
%define name    netatalk
%define version 1.6.0
%define realversion 1.6.0
%define release 2mdk
%define tardir	%{name}-%{realversion}

################################################# BASIC PACKAGE INFORMATION
Summary: Appletalk and Appleshare/IP services for Linux
Name: %{name}
Version: %{version}
Release: %{release}
License: BSD
Group: System/Servers
Source0: %{name}-%{realversion}.tar.bz2
URL: http://netatalk.sourceforge.net/

############################################################## REQUIREMENTS
Requires: cracklib, openssl, tcp_wrappers, pam
BuildRequires: cracklib-devel openssl-devel pam-devel quota libdb3.3-devel
Prereq: rpm-helper

Prefix:    %{_prefix}
BuildRoot: %{_tmppath}/%{name}-buildroot

%description
netatalk is an implementation of the AppleTalk Protocol Suite for Unix/Linux
systems. The current release contains support for Ethertalk Phase I and II,
DDP, RTMP, NBP, ZIP, AEP, ATP, PAP, ASP, and AFP. It provides Appletalk file
printing and routing services on Solaris 2.5, Linux, FreeBSD, SunOS 4.1 and
Ultrix 4. It also supports AFP 2.1 and 2.2 (Appleshare IP).

%package devel
Group: Development/Other
Summary: Appletalk and Appleshare/IP services for Linux development files
%description devel
netatalk is an implementation of the AppleTalk Protocol Suite for Unix/Linux
systems. The current release contains support for Ethertalk Phase I and II,
DDP, RTMP, NBP, ZIP, AEP, ATP, PAP, ASP, and AFP. It provides Appletalk file
printing and routing services on Solaris 2.5, Linux, FreeBSD, SunOS 4.1 and
Ultrix 4. It also supports AFP 2.1 and 2.2 (Appleshare IP).

This package is required for developing appletalk-based applications.

%prep
%setup -q -n %{tardir}/

%build
export PKGLIBDIR=%{_libdir}/netatalk
export LD_PRELOAD=
CFLAGS="$RPM_OPT_FLAGS -fomit-frame-pointer -fsigned-char" ./configure \
	--prefix=%{prefix} \
	--libdir=%{_libdir} \
    	--sysconfdir=%{_sysconfdir} \
	--with-uams-path=%{_libdir}/netatalk/uams \
    	--with-msg-dir=%{_libdir}/netatalk/msg \
	--with-nls-dir=%{_libdir}/netatalk/nls \
	--with-ssl-dirs=%{_prefix} \
	--enable-redhat \
	--with-cracklib \
	--with-pam \
	--with-shadow \
	--with-tcp-wrappers \
	--with-ssl \
	--enable-pgp-uam \
	--enable-timelord \
	--with-did=cnid \
	--enable-dropkludge \
	--disable-shell-check \
	--with-mangling
make all

# make maccode.* codepage files
./etc/afpd/nls/makecode

%install

# clean up zero-byte doc files
# (sb) now this breaks the build!
#find $RPM_BUILD_DIR/%{tardir} -size 0  |xargs rm -f

### INSTALL (USING "make install") ###
mkdir -p $RPM_BUILD_ROOT{%{prefix},%{_sysconfdir}/netatalk/}
mkdir -p $RPM_BUILD_ROOT/%{_libdir}/netatalk
mkdir -p $RPM_BUILD_ROOT/%{_libdir}/netatalk/msg

#make DESTDIR=$RPM_BUILD_ROOT install-strip - breaks on perl script - let rpm strip
make DESTDIR=$RPM_BUILD_ROOT install

# move the nls files out of /etc - for rpmlint - patch should allow this
# now they land in the right place
#mv $RPM_BUILD_ROOT/%{_sysconfdir}/atalk/nls $RPM_BUILD_ROOT/%{_libdir}/netatalk/

# copy config files - install doesn't do it now
cp $RPM_BUILD_DIR/%{name}-%{version}/config/*.conf $RPM_BUILD_ROOT%{_sysconfdir}/netatalk/
cp $RPM_BUILD_DIR/%{name}-%{version}/config/AppleVolumes.* $RPM_BUILD_ROOT%{_sysconfdir}/netatalk/

# bzip2 man pages
for i in 1 3 4 5 8; do
	bzip2 $RPM_BUILD_ROOT/usr/man/man$i/*.$i
	mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man$i
	mv $RPM_BUILD_ROOT/usr/man/man$i/*.$i.bz2 $RPM_BUILD_ROOT/%{_mandir}/man$i/
done

# clean up installed but unpackaged files
rm -f $RPM_BUILD_ROOT/%{_includedir}/netatalk/*.c
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/netatalk/uams/*.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/netatalk/uams/*.a
rm -f $RPM_BUILD_ROOT/%{prefix}/share/netatalk/pagecount.ps

%post
%_post_service atalk
/sbin/ldconfig
# after the first install only
if [ "$1" = 1 ]; then
	# add the ddp lines to /etc/services
	if (grep '[0-9][0-9]*/ddp' /etc/services >/dev/null); then
		cat <<'_EOD1_' >&2
warning: The DDP services appear to be present in /etc/services.
warning: Please check them against services.atalk in the documentation.
_EOD1_
		true
	else
		cat <<'_EOD2_' >>/etc/services
# start of DDP services
#
# Everything between the 'start of DDP services' and 'end of DDP services'
# lines will be automatically deleted when the netatalk package is removed.
#
rtmp		1/ddp		# Routing Table Maintenance Protocol
nbp		2/ddp		# Name Binding Protocol
echo		4/ddp		# AppleTalk Echo Protocol
zip		6/ddp		# Zone Information Protocol

afpovertcp	548/tcp		# AFP over TCP
afpovertcp	548/udp
# end of DDP services
_EOD2_
	fi
fi

%preun
%_preun_service atalk

%postun
# do only for the last un-install
if [ "$1" = 0 ]; then
	# remove the ddp lines from /etc/services
	if (grep '^# start of DDP services$' /etc/services >/dev/null && \
	    grep '^# end of DDP services$'   /etc/services >/dev/null ); then
	  sed -e '/^# start of DDP services$/,/^# end of DDP services$/d' \
	    </etc/services >/etc/services.tmp$$
	  cat /etc/services.tmp$$ >/etc/services
	  rm /etc/services.tmp$$
	else
	  cat <<'_EOD3_' >&2
warning: Unable to find the lines `# start of DDP services` and
warning: `# end of DDP services` in the file /etc/services.
warning: You should remove the DDP services from /etc/services manually.
_EOD3_
	fi
fi

%clean
rm -rf $RPM_BUILD_ROOT
rm -rf $RPM_BUILD_DIR/%{tardir}/

%files
%defattr(-,root,root)
%doc ChangeLog doc/README* doc/DEVELOPER doc/FAQ doc/INSTALL
%dir %{_sysconfdir}/netatalk
%dir %{_libdir}/netatalk/msg
%config(noreplace) %{_sysconfdir}/netatalk/Apple*
%config(noreplace) %{_sysconfdir}/netatalk/*.conf
%config(noreplace) %{_sysconfdir}/pam.d/netatalk
%dir %{_libdir}/netatalk/nls
%{_libdir}/netatalk/nls/*
%dir %{_libdir}/netatalk/uams
%attr(755,root,root) %{_libdir}/netatalk/uams/*.so
%config(noreplace) %attr(755,root,root) %{_initrddir}/atalk
%{prefix}/bin/*
%{prefix}/sbin/*
%{_mandir}/man*/*

%files devel
%defattr(-,root,root)
%{prefix}/lib/*.a
%dir %{prefix}/include/atalk
%{_includedir}/atalk/*.h
%dir %{prefix}/include/netatalk
%{_includedir}/netatalk/*.h
%{prefix}/share/aclocal/netatalk.m4

%changelog
* Fri Dec 27 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.6.0-2mdk
- rebuild for new glibc/rpm

* Mon Dec 9 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.6.0-1mdk
- new version, add --with-mangling (long filenames)
- try did=cnid now that libdb3 is no longer broken on ppc
- BuildRequires libdb3.3-devel, clean installed but not packaged files

* Tue Oct 15 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.5-2mdk
- fix configdir path for initscript
- with-did=last
- limit docs to just docs

* Tue Oct  8 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.5-1mdk
- new version, /etc/atalk->/etc/netatalk
- new config flags: enable-timelord (Macintosh time server daemon)
		    with-did=cnid (Berkeley DB3 scheme)
		    enable-dropkludge (experimental dropbox fix)
		    disable-shell-check (allow users w/o valid shell)
- use newer post/preun macros

* Fri Apr  5 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.3.1-1mdk
- new version

* Thu Mar 21 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.2-1mdk
- new version

* Fri Jan 18 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.1.1-1mdk
- new version

* Thu Jan 17 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.0-3mdk
- correct configure flags to fix init script and location of atalkd.tmp 
- setup codepage files and place in /usr/lib/atalk
- Thanks - Frederic Corne, Tomas Perez
- build with new spec-helper to address initscript issue
 
* Sun Jan  6 2002 Stefan van der Eijk <stefan@eijk.nu> 1.5.0-2mdk
- BuildRequires: quota (rpcsvc/rquota.h)
- fix install of config files

* Wed Jan  2 2002 Stew Benedict <sbenedict@mandrakesoft.com> 1.5.0-1mdk
- 1.5 release, spec mods

* Thu Nov  8 2001 Stew Benedict <sbenedict@mandrakesoft.com> 1.5_pre6-1mdk
- SRPM from sourceforge - cleanup spec a bit - rpmlint/FHS conformance

* Thu Apr 12 2001 rufus t firefly <rufus.t.firefly@linux-mandrake.com>
  - v1.5pre6-1mdk
  - pre-release 6 for sourceforge

* Wed Mar 07 2001 rufus t firefly <rufus.t.firefly@linux-mandrake.com>
  - v1.5pre5-1mdk
  - pre-release 5 for sourceforge
  - sync with redhat package

* Mon Dec 18 2000 rufus t firefly <rufus.t.firefly@linux-mandrake.com>
  - v1.5pre3-1mdk
  - pre-release 3 for sourceforge
  - moved away from 1.4.99 ... 

* Wed Nov 08 2000 rufus t firefly <rufus.t.firefly@linux-mandrake.com>
  - v1.4.99-0.20001108mdk
  - pre-release 2 for sourceforge

* Wed Sep 27 2000 rufus t firefly <rufus.t.firefly@linux-mandrake.com>
  - v1.4.99-0.20000927mdk
  - pre-release 1 for sourceforge

